Package: graphpcor
Type: Package
Title: Models for Correlation Matrices Based on Graphs
Version: 0.1.25
Maintainer: Elias Teixeira Krainski <elias.krainski@kaust.edu.sa>
Authors@R: c(
 person(given = c("Elias"),
        family = "Teixeira Krainski",
        email = "elias.krainski@kaust.edu.sa",
        role = c("cre", "aut", "cph"),
        comment = c(ORCID = "0000-0002-7063-2615")),
 person(given = "Denis",
        family = "Rustand",
        role = c("aut", "cph"),
        comment = c(ORCID = "0000-0001-9708-5220")),
 person(given = "Anna",
        family = "Freni-Sterrantino",
        role = c("aut", "cph"),
        comment = c(ORCID = "0000-0002-6602-6209")),
 person(given = "Janet",
        family = "van Niekerk",
        role = c("aut", "cph"),
        comment = c(ORCID = "0000-0002-4334-2057")),
 person(given = "Haavard",
        family = "Rue’",
        role = "aut",
        comment = c(ORCID = "0000-0002-0222-1881"))
        )
Description: Implement some models for 
  correlation/covariance matrices including two approaches 
  to model correlation matrices from a graphical structure.
  One use latent parent variables as proposed in
  Sterrantino et. al. (2024) <doi:10.1007/s10260-025-00788-y>.
  The other uses a graph to specify conditional 
  relations between the variables.
  The graphical structure makes correlation matrices 
  interpretable and avoids the quadratic increase of 
  parameters as a function of the dimension. 
  In the first approach a natural sequence of simpler 
  models along with a complexity penalization is used.
  The second penalizes deviations from a base model.
  These can be used as prior for model parameters,
  considering C code through the 'cgeneric' interface 
  for the 'INLA' package (<https://www.r-inla.org>). 
  This allows one to use these models as building 
  blocks combined and to other latent Gaussian models 
  in order to build complex data models.
Additional_repositories: https://inla.r-inla-download.org/R/testing
License: GPL (>= 2)
Encoding: UTF-8
NeedsCompilation: yes
Depends: R (>= 4.3), Matrix, INLAtools (> 0.1.3), numDeriv
Imports: methods, stats, utils, igraph
Suggests: knitr, INLA (>= 24.02.09)
BuildVignettes: true
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
Packaged: 2026-05-07 08:50:03 UTC; eliask
Author: Elias Teixeira Krainski [cre, aut, cph] (ORCID:
    <https://orcid.org/0000-0002-7063-2615>),
  Denis Rustand [aut, cph] (ORCID:
    <https://orcid.org/0000-0001-9708-5220>),
  Anna Freni-Sterrantino [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-6602-6209>),
  Janet van Niekerk [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-4334-2057>),
  Haavard Rue’ [aut] (ORCID: <https://orcid.org/0000-0002-0222-1881>)
Repository: CRAN
Date/Publication: 2026-05-07 13:40:07 UTC
Built: R 4.6.0; ; 2026-05-07 14:07:40 UTC; unix
