# Generated by roxygen2: do not edit by hand

S3method(Laplacian,Matrix)
S3method(Laplacian,default)
S3method(Laplacian,graphpcor)
S3method(Laplacian,matrix)
S3method(basecor,matrix)
S3method(basecor,numeric)
S3method(basepcor,matrix)
S3method(basepcor,numeric)
S3method(cgeneric,Matrix)
S3method(cgeneric,basecor)
S3method(cgeneric,graphpcor)
S3method(cgeneric,treepcor)
S3method(dim,graphpcor)
S3method(dim,treepcor)
S3method(drop1,treepcor)
S3method(edges,default)
S3method(edges,graphpcor)
S3method(edges,treepcor)
S3method(graphpcor,Matrix)
S3method(graphpcor,character)
S3method(graphpcor,formula)
S3method(graphpcor,list)
S3method(graphpcor,matrix)
S3method(hessian,basecor)
S3method(hessian,basepcor)
S3method(hessian,graphpcor)
S3method(plot,graphpcor)
S3method(plot,treepcor)
S3method(print,basecor)
S3method(print,basepcor)
S3method(print,graphpcor)
S3method(print,treepcor)
S3method(summary,graphpcor)
S3method(summary,treepcor)
S3method(vcov,graphpcor)
S3method(vcov,treepcor)
export(Laplacian)
export(basecor)
export(basepcor)
export(cholcor)
export(dLKJ)
export(edges)
export(gphcQ)
export(graphpcor)
export(stan_add)
export(tpcQ)
export(treepcor)
importFrom(INLAtools,Sparse)
importFrom(INLAtools,cgeneric)
importFrom(INLAtools,cgeneric_Q)
importFrom(INLAtools,cgeneric_graph)
importFrom(INLAtools,cgeneric_initial)
importFrom(INLAtools,cgeneric_prior)
importFrom(INLAtools,is.zero)
importFrom(INLAtools,packageCheck)
importFrom(INLAtools,upperPadding)
importFrom(Matrix,Diagonal)
importFrom(Matrix,Matrix)
importFrom(Matrix,colSums)
importFrom(Matrix,forceSymmetric)
importFrom(Matrix,t)
importFrom(grDevices,rgb)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(methods,getMethod)
importFrom(methods,new)
importFrom(numDeriv,hessian)
importFrom(stats,as.formula)
importFrom(stats,cov2cor)
importFrom(stats,drop1)
importFrom(stats,rexp)
importFrom(stats,runif)
importFrom(stats,vcov)
importFrom(utils,tail)
